<?php
/**
 * Describe child theme functions
 *
 * @package SparkleStore
 * @subpackage Store Press
 * 
 */

/*-------------------------------------------------------------------------------------------------------------------------------*/
if ( ! function_exists( 'store_press_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function store_press_setup() {
        $store_press_theme_info = wp_get_theme();
        $GLOBALS['store_press_version'] = $store_press_theme_info->get( 'Version' );

        add_theme_support( "title-tag" );
        add_theme_support( 'automatic-feed-links' );
    }
endif;

add_action( 'after_setup_theme', 'store_press_setup' );

/**
 * Enqueue child theme styles and scripts
*/
add_action( 'wp_enqueue_scripts', 'store_press_scripts', 20 );

function store_press_scripts() {
    
    global $store_press_version;

    wp_enqueue_style( 'wpb-google-fonts', 'https://fonts.googleapis.com/css2?family=Nunito:ital,wght@0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap', false ); 

    wp_dequeue_style( 'sparklestore-style' );
    
    wp_enqueue_script( 'store-press', get_stylesheet_directory_uri()."/assets/store-press.js", array('jquery') );
    wp_enqueue_script( 'jquery.countdown', get_stylesheet_directory_uri()."/assets/jquery.countdown.js", array('jquery') );
	wp_enqueue_style( 'sparklestore-parent-style', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/style.css', array(), esc_attr( $store_press_version ) );
	wp_enqueue_style( 'sparklestore-parent-responsive-style', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/assets/css/responsive.css', array(), esc_attr( $store_press_version ) );

    wp_enqueue_style( 'store-press-style', get_stylesheet_uri(), array(), esc_attr( $store_press_version ) );
    wp_enqueue_style( 'store-responsive-style', get_stylesheet_uri(), array(), esc_attr( $store_press_version ) );
    
}

if ( ! function_exists( 'store_press_child_options' ) ) {
    function store_press_child_options( $wp_customize ) {
        $wp_customize->get_control('sparklestore_banner_promo_style')->choices = array(
            'right' => esc_html__('Right', 'store-press'),
            'left' => esc_html__('Left', 'store-press'),
            'bottom' => esc_html__('Bottom', 'store-press'),
        );
    }
}
add_action( 'customize_register' , 'store_press_child_options', 11 );

/**
 * Dynamic css
*/
if ( ! function_exists( 'store_press_dynamic_css' ) ) {

    function store_press_dynamic_css() {
        
        $primary_color = get_theme_mod('sparklestore_primary_theme_color_options', '#003772');
        $rgba = sparklestore_hex2rgba($primary_color, 0.8);
        $sparklestore_colors = '';

        $sparklestore_colors ="
        .site-cart-items-wrap .count{
            background-color: {$primary_color};
        }
        .sub-footer-inner .coppyright a{
            color: {$primary_color};
        }
        ";


        $second_color = get_theme_mod('sparklestore_secondary_theme_color_options', '#f33c3c');
        $sparklestore_colors .="
        .chosen-container-single .chosen-single,
        .chosen-container-active.chosen-with-drop .chosen-single{
            background-color: {$second_color};
        }
        ";

        wp_add_inline_style( 'store-responsive-style', $sparklestore_colors );
    }
}
add_action( 'wp_enqueue_scripts', 'store_press_dynamic_css', 99 );